import React from 'react';
import { render, cleanup, fireEvent, waitFor } from '@testing-library/react';
import '@testing-library/jest-dom/extend-expect';

import Accordion from '.';

const module = {
  items: [
    { title: 'one', content: 'first content' },
    { title: 'two', content: 'second content' },
    { title: 'three', content: 'third content' },
  ],
  style: 'template_one',
};

const commentsModule = {
  items: [
    { title: 'one', content: 'first content' },
    { title: 'two', content: 'second content' },
    { title: 'three', content: 'third content' },
  ],
  style: 'template_two',
};

const page = {
  author: [
    {
      profile_page_path: '',
      name: 'John Doe',
      image: '',
    },
  ],
};

describe('Accordions Component', () => {
  test('render with props', async () => {
    const { container, getByText } = render(
      <Accordion page={page} module={module} openAll={false} closeOthers={false} />
    );

    await waitFor(() => {
      expect(container.querySelectorAll('button.title')).toHaveLength(3);
      expect(getByText('one')).toBeTruthy();
      expect(getByText('second content')).toBeTruthy();
    });
  });

  test('open item', async () => {
    const { container } = render(
      <Accordion module={module} openAll={false} openItem={2} closeOthers={false} />
    );
    await waitFor(() => {
      expect(container.querySelectorAll('button.title')[1].getAttribute('class')).toContain(
        'invertArrow'
      );
    });
  });

  test('open all', async () => {
    const { container } = render(<Accordion module={module} openAll closeOthers={false} />);
    await waitFor(() => {
      expect(container.querySelectorAll('button.invertArrow')).toHaveLength(3);
    });
  });

  test('close others when open one', async () => {
    const { container } = render(
      <Accordion module={module} openItem={1} openAll={false} closeOthers />
    );
    await waitFor(() => {
      const thirdtItemBtn = container.querySelectorAll('button')[2];
      fireEvent.click(thirdtItemBtn);
      const items = container.querySelectorAll('button.title');
      expect(items[2].getAttribute('class')).toContain('invertArrow');
      expect(items[1].getAttribute('class')).toEqual('title accordion-gtm btn-cta');
      expect(items[0].getAttribute('class')).toEqual('title accordion-gtm btn-cta');
    });
  });

  test('comment section accordian', async () => {
    const { container, getByText } = render(<Accordion module={commentsModule} page={page} />);
    await waitFor(() => {
      expect(container.querySelectorAll('.question')).toHaveLength(3);
      expect(getByText('one')).toBeTruthy();
      expect(getByText('second content')).toBeTruthy();
    });
  });

  test('do not close others when open one', async () => {
    const { container } = render(
      <Accordion module={module} openItem={1} openAll={false} closeOthers={false} />
    );
    await waitFor(() => {
      const thirdtItemBtn = container.querySelectorAll('button')[2];
      fireEvent.click(thirdtItemBtn);
      const items = container.querySelectorAll('button.title');
      expect(items[2].getAttribute('class')).toContain('invertArrow');
      expect(items[1].getAttribute('class')).toEqual('title accordion-gtm btn-cta');
      expect(items[0].getAttribute('class')).toContain('invertArrow');
    });
  });
});
afterEach(() => {
  cleanup();
});
