import React, { useRef, useEffect } from 'react';
import PropTypes from 'prop-types';

import styles from './template-one.module.scss';
import keygen from '~helpers/keygen';

const TemplateOne = ({ module, openAll = false, openItem, closeOthers = false }) => {
  const { items } = module;
  const itemRefs = useRef([]);
  const btnRefs = useRef([]);

  const openAllItems = () => {
    for (let i = 0; i < itemRefs.current.length; i += 1) {
      if (itemRefs.current[i] !== undefined) {
        itemRefs.current[i][0].classList.add(styles.active);
        btnRefs.current[i][0].classList.add(styles.invertArrow);
      }
    }
  };

  const openSingleItem = (index) => {
    itemRefs.current.filter((ref) => ref.length > 0);
    if (itemRefs.current[index]) {
      itemRefs.current[index][0].classList.add(styles.active);
      btnRefs.current[index][0].classList.add(styles.invertArrow);
    }
  };

  const closeOtherItems = (index) => {
    for (let i = 0; i < itemRefs.current.length; i += 1) {
      if (i !== index) {
        itemRefs.current[i][0].classList.remove(styles.active);
        btnRefs.current[i][0].classList.remove(styles.invertArrow);
      }
    }
  };

  // toggle open/close an item
  const toggle = (index) => {
    btnRefs.current[index][0].classList.toggle(styles.invertArrow);
    itemRefs.current[index][0].classList.toggle(styles.active);
    if (closeOthers) {
      closeOtherItems(index);
    }
  };

  useEffect(() => {
    if (openAll) {
      openAllItems();
    }
  }, [openAll]);
  useEffect(() => {
    if (openItem) {
      openSingleItem(openItem - 1);
    }
  }, [openItem]);

  return (
    <>
      <div className={styles.accordionContainer || ''}>
        {items.map(
          (item, index) =>
            item.content && (
              <div key={keygen()} className={styles.accordionItem || ''}>
                <button
                  onClick={() => toggle(index)}
                  className={`${styles.title || ''} accordion-gtm btn-cta`}
                  type="button"
                  ref={(el) => {
                    btnRefs.current[index] = btnRefs.current[index] || [];
                    btnRefs.current[index].push(el);
                  }}
                >
                  <div dangerouslySetInnerHTML={{ __html: item.title }} />
                </button>
                <div
                  className={styles.content || ''}
                  ref={(el) => {
                    itemRefs.current[index] = itemRefs.current[index] || [];
                    itemRefs.current[index].push(el);
                  }}
                >
                  <div dangerouslySetInnerHTML={{ __html: item.content }} />
                </div>
              </div>
            )
        )}
      </div>
    </>
  );
};

TemplateOne.propTypes = {
  module: PropTypes.shape({
    anchor_label: PropTypes.string,
    items: PropTypes.arrayOf(
      PropTypes.shape({
        title: PropTypes.string,
        content: PropTypes.string,
      })
    ),
  }).isRequired,
  openAll: PropTypes.bool,
  openItem: PropTypes.number,
  closeOthers: PropTypes.bool,
  styles: PropTypes.shape({}),
};

export default TemplateOne;
