/* eslint-disable camelcase */
/* eslint-disable no-useless-concat */
/* eslint-disable no-restricted-globals */
import React, { useEffect } from 'react';
import PropTypes from 'prop-types';
// eslint-disable-next-line import/no-extraneous-dependencies
import { v4 as uuidv4 } from 'uuid';
import { getSection } from '~helpers/getters';
import Header from '~molecules/header';
import Main from '~molecules/main';
import Footer from '~molecules/footer';
import Navigation from '~organisms/navigation';
import FloatingArea from '../../molecules/floating-area';
import styles from './body.module.scss';
import { setCookie, getCookie } from '~helpers/cookies';

function Body({ pageContext, children, serverData }) {
  const getBodySection = (name) => getSection(name, pageContext);
  const { template } = pageContext.page;
  const is404 = pageContext?.page?.path?.includes('404');
  const main = getBodySection('main');
  const navigation = getBodySection('navigation');
  const rgNavigation = getBodySection('rg_navigation');
  const footer = getBodySection('footer');
  const isRGpage = template === 'responsible_gambling_guide';

  useEffect(() => {
    if (!getCookie('affUUID')) {
      setCookie('affUUID', uuidv4());
    }
  }, []);

  return (
    <>
      {(rgNavigation || navigation) && (
        <Navigation
          template={template}
          pageContext={pageContext}
          section={isRGpage ? rgNavigation : navigation}
          orientation="horizontal"
          mobileAnimation="collapseFull"
          stopScrollOnOpen
          canOpenAllSubMenus
        />
      )}
      {!is404 && <Header serverData={serverData} section={pageContext} />}
      {main && !children && (
        <Main serverData={serverData} section={main} pageContext={pageContext} />
      )}
      {children && <main>{children}</main>}
      <Footer template={template} section={footer} />
      <FloatingArea pageContext={pageContext} template={template} customStyles={styles} />
    </>
  );
}

Body.propTypes = {
  children: PropTypes.element,
  // eslint-disable-next-line react/forbid-prop-types
  serverData: PropTypes.shape({}),
  pageContext: PropTypes.shape({
    page: PropTypes.shape({
      id: PropTypes.number,
      relation_type: PropTypes.string,
      path: PropTypes.string,
      template: PropTypes.string,
      relation: PropTypes.shape({
        status: PropTypes.string,
        logo_url: PropTypes.string,
      }),
      market: PropTypes.string,
    }),
    marketSections: PropTypes.shape({
      footer_navigation: PropTypes.shape({}),
      popup: PropTypes.shape({
        modules: PropTypes.arrayOf({}),
      }),
    }),
  }).isRequired,
};

export default Body;
